@@ -4,8 +4,9 @@
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
+use crate::{Server, auth::AccessToken};
 use directory::{
-    QueryBy, Type,
+    QueryParams, Type,
     backend::internal::{
         PrincipalField,
         manage::{ChangedPrincipals, ManageDirectory},
@@ -21,8 +22,6 @@ use jmap_proto::{
 };
 use utils::map::bitmap::Bitmap;
 
-use crate::{Server, auth::AccessToken};
-
 impl Server {
     pub async fn acl_set(
         &self,
@@ -215,7 +214,7 @@ impl Server {
                     .core
                     .storage
                     .directory
-                    .query(QueryBy::Name(account_name), false)
+                    .query(QueryParams::name(account_name).with_return_member_of(false))
                     .await
                 {
                     Ok(Some(principal)) => {
@@ -256,7 +255,7 @@ impl Server {
                 .core
                 .storage
                 .directory
-                .query(QueryBy::Name(account_name), false)
+                .query(QueryParams::name(account_name).with_return_member_of(false))
                 .await
             {
                 Ok(Some(principal)) => Ok((
