@@ -1,9 +1,10 @@
 /*
- * SPDX-FileCopyrightText: 2020 Stalwart Labs Ltd <hello@stalw.art>
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
  *
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
+use calcard::common::timezone::Tz;
 use common::{DavName, Server, auth::AccessToken};
 use dav_proto::{Depth, RequestHeaders};
 use groupware::{
@@ -17,7 +18,7 @@ use jmap_proto::types::{
     acl::Acl,
     collection::{Collection, SyncCollection, VanishedCollection},
 };
-use store::write::BatchBuilder;
+use store::write::{BatchBuilder, now};
 use trc::AddContext;
 
 use crate::{
@@ -63,6 +64,21 @@ impl CalendarCopyMoveRequestHandler for Server {
         let from_resource = from_resources
             .by_path(from_resource_name)
             .ok_or(DavError::Code(StatusCode::NOT_FOUND))?;
+        #[cfg(not(debug_assertions))]
+        if is_move
+            && from_resource.is_container()
+            && self
+                .core
+                .groupware
+                .default_calendar_name
+                .as_ref()
+                .is_some_and(|name| name == from_resource_name)
+        {
+            return Err(DavError::Condition(crate::DavErrorCondition::new(
+                StatusCode::FORBIDDEN,
+                dav_proto::schema::response::CalCondition::DefaultCalendarNeeded,
+            )));
+        }
 
         // Validate ACL
         if !access_token.is_member(from_account_id)
@@ -242,6 +258,7 @@ impl CalendarCopyMoveRequestHandler for Server {
                             to_resource.document_id().into(),
                             to_calendar_id,
                             new_name,
+                            headers.if_schedule_tag,
                         )
                         .await
                     } else {
@@ -309,6 +326,7 @@ impl CalendarCopyMoveRequestHandler for Server {
                             None,
                             to_calendar_id,
                             new_name,
+                            headers.if_schedule_tag,
                         )
                         .await
                     } else {
@@ -480,6 +498,7 @@ async fn copy_event(
             )
             .caused_by(trc::location!())?;
     } else {
+        let next_email_alarm = event.inner.data.next_alarm(now() as i64, Tz::Floating);
         let mut new_event = event
             .deserialize::<CalendarEvent>()
             .caused_by(trc::location!())?;
@@ -493,7 +512,13 @@ async fn copy_event(
             .await
             .caused_by(trc::location!())?;
         new_event
-            .insert(access_token, to_account_id, to_document_id, &mut batch)
+            .insert(
+                access_token,
+                to_account_id,
+                to_document_id,
+                next_email_alarm,
+                &mut batch,
+            )
             .caused_by(trc::location!())?;
     }
 
@@ -515,6 +540,7 @@ async fn copy_event(
                     to_document_id,
                     to_calendar_id,
                     None,
+                    false,
                     &mut batch,
                 )
                 .caused_by(trc::location!())?;
@@ -545,6 +571,7 @@ async fn move_event(
     to_document_id: Option<u32>,
     to_calendar_id: u32,
     new_name: &str,
+    if_schedule_tag: Option<u32>,
 ) -> crate::Result<HttpResponse> {
     // Fetch event
     let event_ = server
@@ -556,6 +583,13 @@ async fn move_event(
         .to_unarchived::<CalendarEvent>()
         .caused_by(trc::location!())?;
 
+    // Validate headers
+    if if_schedule_tag.is_some()
+        && event.inner.schedule_tag.as_ref().map(|t| t.to_native()) != if_schedule_tag
+    {
+        return Err(DavError::Code(StatusCode::PRECONDITION_FAILED));
+    }
+
     // Validate UID
     if from_account_id != to_account_id
         || from_calendar_id != to_calendar_id
@@ -610,6 +644,7 @@ async fn move_event(
             .caused_by(trc::location!())?;
         batch.log_vanished_item(VanishedCollection::Calendar, from_resource_path);
     } else {
+        let next_email_alarm = event.inner.data.next_alarm(now() as i64, Tz::Floating);
         let mut new_event = event
             .deserialize::<CalendarEvent>()
             .caused_by(trc::location!())?;
@@ -625,6 +660,7 @@ async fn move_event(
                 from_document_id,
                 from_calendar_id,
                 from_resource_path.into(),
+                false,
                 &mut batch,
             )
             .caused_by(trc::location!())?;
@@ -635,7 +671,13 @@ async fn move_event(
             .await
             .caused_by(trc::location!())?;
         new_event
-            .insert(access_token, to_account_id, to_document_id, &mut batch)
+            .insert(
+                access_token,
+                to_account_id,
+                to_document_id,
+                next_email_alarm,
+                &mut batch,
+            )
             .caused_by(trc::location!())?;
     }
 
@@ -657,6 +699,7 @@ async fn move_event(
                     to_document_id,
                     to_calendar_id,
                     None,
+                    false,
                     &mut batch,
                 )
                 .caused_by(trc::location!())?;
@@ -795,6 +838,7 @@ async fn copy_container(
                     to_document_id,
                     to_children_ids,
                     None,
+                    false,
                     &mut batch,
                 )
                 .await
@@ -869,6 +913,7 @@ async fn copy_container(
                     )
                     .caused_by(trc::location!())?;
             } else {
+                let next_email_alarm = event.inner.data.next_alarm(now() as i64, Tz::Floating);
                 if remove_source {
                     DestroyArchive(event)
                         .delete(
@@ -877,11 +922,11 @@ async fn copy_container(
                             from_child_document_id,
                             from_document_id,
                             None,
+                            false,
                             &mut batch,
                         )
                         .caused_by(trc::location!())?;
                 }
-
                 let to_document_id = server
                     .store()
                     .assign_document_ids(to_account_id, Collection::CalendarEvent, 1)
@@ -890,7 +935,13 @@ async fn copy_container(
                 new_event.names = vec![new_name];
                 required_space += new_event.size as u64;
                 new_event
-                    .insert(access_token, to_account_id, to_document_id, &mut batch)
+                    .insert(
+                        access_token,
+                        to_account_id,
+                        to_document_id,
+                        next_email_alarm,
+                        &mut batch,
+                    )
                     .caused_by(trc::location!())?;
             }
         }
