@@ -275,11 +275,11 @@ impl CalendarQueryHandler {
                                     let mut matched_any = false;
 
                                     for value in entry.values.iter() {
-                                        if let Some(text) = value.as_text() {
-                                            if text_match.matches(text) {
-                                                matched_any = true;
-                                                break;
-                                            }
+                                        if let Some(text) = value.as_text()
+                                            && text_match.matches(text)
+                                        {
+                                            matched_any = true;
+                                            break;
                                         }
                                     }
 
@@ -420,7 +420,12 @@ impl CalendarQueryHandler {
         is_all || matches_one
     }
 
-    pub fn serialize_ical(&mut self, event: &ArchivedCalendarEvent, data: &CalendarData) -> String {
+    pub fn serialize_ical(
+        &mut self,
+        event: &ArchivedCalendarEvent,
+        data: &CalendarData,
+        instances_limit: &mut usize,
+    ) -> Option<String> {
         let mut out = String::with_capacity(event.size.to_native() as usize);
         let _v = [0.into()];
         let mut component_iter: Iter<'_, rkyv::rend::u16_le> = _v.iter();
@@ -443,31 +448,29 @@ impl CalendarQueryHandler {
                     .unwrap();
 
                 // Limit recurrence override
-                if let Some(limit_recurrence) = &data.limit_recurrence {
-                    if component.is_recurrence_override()
-                        && !self.expanded_times.iter().any(|event| {
-                            event.comp_id == component_id
-                                && limit_recurrence.is_in_range(
-                                    component.component_type == ICalendarComponentType::VTodo,
-                                    event.start,
-                                    event.end,
-                                )
-                        })
-                    {
-                        continue;
-                    }
+                if let Some(limit_recurrence) = &data.limit_recurrence
+                    && component.is_recurrence_override()
+                    && !self.expanded_times.iter().any(|event| {
+                        event.comp_id == component_id
+                            && limit_recurrence.is_in_range(
+                                component.component_type == ICalendarComponentType::VTodo,
+                                event.start,
+                                event.end,
+                            )
+                    })
+                {
+                    continue;
                 }
 
                 // Limit freebusy
-                if let Some(limit_recurrence) = &data.limit_freebusy {
-                    if component.component_type == ICalendarComponentType::VFreebusy
-                        && !self.expanded_times.iter().any(|event| {
-                            event.comp_id == component_id
-                                && limit_recurrence.is_in_range(false, event.start, event.end)
-                        })
-                    {
-                        continue;
-                    }
+                if let Some(limit_recurrence) = &data.limit_freebusy
+                    && component.component_type == ICalendarComponentType::VFreebusy
+                    && !self.expanded_times.iter().any(|event| {
+                        event.comp_id == component_id
+                            && limit_recurrence.is_in_range(false, event.start, event.end)
+                    })
+                {
+                    continue;
                 }
 
                 // Filter entries
@@ -530,6 +533,11 @@ impl CalendarQueryHandler {
                             && (!is_recurrent_or_override
                                 || expand.is_in_range(is_todo, event.start, event.end))
                         {
+                            if *instances_limit > 0 {
+                                *instances_limit -= 1;
+                            } else {
+                                return None;
+                            }
                             let _ = write!(&mut out, "BEGIN:{component_name}\r\n");
 
                             // Write DTSTART, DTEND and RECURRENCE-ID
@@ -609,7 +617,7 @@ impl CalendarQueryHandler {
             }
         }
 
-        out
+        Some(out)
     }
 
     pub fn into_expanded_times(self) -> Vec<CalendarEvent<i64, i64>> {
