@@ -75,10 +75,6 @@ pub(crate) enum DavQueryResource<'x> {
         parent_collection: Collection,
         items: Vec<PropFindItem>,
     },
-    Discovery {
-        parent_collection: Collection,
-        account_ids: Vec<u32>,
-    },
     #[default]
     None,
 }
@@ -303,29 +299,6 @@ impl<'x> DavQuery<'x> {
         }
     }
 
-    pub fn discovery(
-        propfind: PropFind,
-        account_ids: Vec<u32>,
-        collection: Collection,
-        headers: &RequestHeaders<'x>,
-    ) -> Self {
-        Self {
-            resource: DavQueryResource::Discovery {
-                parent_collection: collection,
-                account_ids,
-            },
-            propfind,
-            depth: 0,
-            ret: headers.ret,
-            depth_no_root: headers.depth_no_root,
-            uri: headers.uri,
-            sync_type: Default::default(),
-            limit: Default::default(),
-            max_vcard_version: headers.max_vcard_version,
-            expand: false,
-        }
-    }
-
     pub fn is_minimal(&self) -> bool {
         self.ret == Return::Minimal
     }
