@@ -426,7 +426,7 @@ pub(crate) async fn build_home_set(
         percent_encoding::utf8_percent_encode(name, RFC_3986),
     )));
 
-    if account_id == access_token.primary_id() {
+    if !server.core.groupware.assisted_discovery && account_id == access_token.primary_id() {
         for account_id in access_token.all_ids_by_collection(collection) {
             if account_id != access_token.primary_id() {
                 let other_name = server
