@@ -33,18 +33,17 @@ pub(crate) async fn update_email_cache(
     };
 
     for (document_id, is_update) in changed_ids {
-        if *is_update {
-            if let Some(archive) = server
+        if *is_update
+            && let Some(archive) = server
                 .get_archive(account_id, Collection::Email, *document_id)
                 .await
                 .caused_by(trc::location!())?
-            {
-                insert_item(
-                    &mut new_cache,
-                    *document_id,
-                    archive.to_unarchived::<MessageData>()?,
-                );
-            }
+        {
+            insert_item(
+                &mut new_cache,
+                *document_id,
+                archive.to_unarchived::<MessageData>()?,
+            );
         }
     }
 
