@@ -557,16 +557,15 @@ impl ParseHttp for Server {
             "metrics" => match path.next().unwrap_or_default() {
                 "prometheus" => {
                     if let Some(prometheus) = &self.core.metrics.prometheus {
-                        if let Some(auth) = &prometheus.auth {
-                            if req
+                        if let Some(auth) = &prometheus.auth
+                            && req
                                 .authorization_basic()
                                 .is_none_or(|secret| secret != auth)
-                            {
-                                return Err(trc::AuthEvent::Failed
-                                    .into_err()
-                                    .details("Invalid or missing credentials.")
-                                    .caused_by(trc::location!()));
-                            }
+                        {
+                            return Err(trc::AuthEvent::Failed
+                                .into_err()
+                                .details("Invalid or missing credentials.")
+                                .caused_by(trc::location!()));
                         }
 
                         return Ok(Resource::new(
@@ -814,33 +813,35 @@ async fn handle_session<T: SessionStream>(inner: Arc<Inner>, session: SessionDat
         .with_upgrades()
         .await
     {
-        match inner
-            .build_server()
-            .is_scanner_fail2banned(session.remote_ip)
-            .await
-        {
-            Ok(true) => {
-                trc::event!(
-                    Security(SecurityEvent::ScanBan),
-                    SpanId = session.session_id,
-                    RemoteIp = session.remote_ip,
-                    Reason = http_err.to_string(),
-                );
-            }
-            Ok(false) => {
-                trc::event!(
-                    Http(trc::HttpEvent::Error),
-                    SpanId = session.session_id,
-                    Reason = http_err.to_string(),
-                );
-            }
-            Err(err) => {
-                trc::error!(
-                    err.span_id(session.session_id)
-                        .details("Failed to check for fail2ban")
-                );
+        if http_err.is_parse() {
+            let server = inner.build_server();
+            if !server.core.jmap.http_use_forwarded {
+                match server.is_scanner_fail2banned(session.remote_ip).await {
+                    Ok(true) => {
+                        trc::event!(
+                            Security(SecurityEvent::ScanBan),
+                            SpanId = session.session_id,
+                            RemoteIp = session.remote_ip,
+                            Reason = http_err.to_string(),
+                        );
+                        return;
+                    }
+                    Ok(false) => {}
+                    Err(err) => {
+                        trc::error!(
+                            err.span_id(session.session_id)
+                                .details("Failed to check for fail2ban")
+                        );
+                    }
+                }
             }
         }
+
+        trc::event!(
+            Http(trc::HttpEvent::Error),
+            SpanId = session.session_id,
+            Reason = http_err.to_string(),
+        );
     }
 }
 
