@@ -40,8 +40,8 @@ impl<T: SessionStream> Session<T> {
         self.assert_has_permission(Permission::ImapAuthenticate)?;
 
         let op_start = Instant::now();
-        let arguments = request.parse_acl(self.version)?;
-        let is_rev2 = self.version.is_rev2();
+        let arguments = request.parse_acl(self.is_utf8)?;
+        let is_utf8 = self.version.is_rev2() || self.is_utf8;
         let data = self.state.session_data();
 
         spawn_op!(data, {
@@ -54,7 +54,32 @@ impl<T: SessionStream> Session<T> {
                 .to_unarchived::<email::mailbox::Mailbox>()
                 .imap_ctx(&arguments.tag, trc::location!())?;
 
+            // Add the current user if they are the owner or a group member
+            if data.access_token.is_member(mailbox_id.account_id) {
+                permissions.push((
+                    data.access_token.name.clone(),
+                    vec![
+                        Rights::Read,
+                        Rights::Lookup,
+                        Rights::Insert,
+                        Rights::DeleteMessages,
+                        Rights::Expunge,
+                        Rights::Seen,
+                        Rights::Write,
+                        Rights::CreateMailbox,
+                        Rights::DeleteMailbox,
+                        Rights::Post,
+                        Rights::Administer,
+                    ],
+                ));
+            }
+
             for item in mailbox.inner.acls.iter() {
+                if item.account_id == mailbox_id.account_id {
+                    // Skip the current user, as they are already added above
+                    continue;
+                }
+
                 if let Some(account_name) = data
                     .server
                     .store()
@@ -124,7 +149,7 @@ impl<T: SessionStream> Session<T> {
                             mailbox_name: arguments.mailbox_name.to_string(),
                             permissions,
                         }
-                        .into_bytes(is_rev2),
+                        .into_bytes(is_utf8),
                     ),
             )
             .await
@@ -136,9 +161,9 @@ impl<T: SessionStream> Session<T> {
         self.assert_has_permission(Permission::ImapMyRights)?;
 
         let op_start = Instant::now();
-        let arguments = request.parse_acl(self.version)?;
+        let arguments = request.parse_acl(self.is_utf8)?;
         let data = self.state.session_data();
-        let is_rev2 = self.version.is_rev2();
+        let is_utf8 = self.version.is_rev2() || self.is_utf8;
 
         spawn_op!(data, {
             let (mailbox_id, mailbox_, access_token) = data
@@ -188,6 +213,7 @@ impl<T: SessionStream> Session<T> {
                     Rights::CreateMailbox,
                     Rights::DeleteMailbox,
                     Rights::Post,
+                    Rights::Administer,
                 ]
             };
 
@@ -212,7 +238,7 @@ impl<T: SessionStream> Session<T> {
                             mailbox_name: arguments.mailbox_name.to_string(),
                             rights,
                         }
-                        .into_bytes(is_rev2),
+                        .into_bytes(is_utf8),
                     ),
             )
             .await
@@ -225,7 +251,7 @@ impl<T: SessionStream> Session<T> {
 
         let op_start = Instant::now();
         let command = request.command;
-        let arguments = request.parse_acl(self.version)?;
+        let arguments = request.parse_acl(self.is_utf8)?;
         let data = self.state.session_data();
 
         spawn_op!(data, {
@@ -371,7 +397,7 @@ impl<T: SessionStream> Session<T> {
         self.assert_has_permission(Permission::ImapListRights)?;
 
         let op_start = Instant::now();
-        let arguments = request.parse_acl(self.version)?;
+        let arguments = request.parse_acl(self.is_utf8)?;
 
         trc::event!(
             Imap(trc::ImapEvent::ListRights),
@@ -399,7 +425,7 @@ impl<T: SessionStream> Session<T> {
                             vec![Rights::Administer],
                         ],
                     }
-                    .into_bytes(self.version.is_rev2()),
+                    .into_bytes(self.version.is_rev2() || self.is_utf8),
                 ),
         )
         .await
