@@ -18,7 +18,6 @@ use jmap_proto::{
 };
 use mail_parser::MessageParser;
 use std::future::Future;
-use trc::AddContext;
 use utils::map::vec_map::VecMap;
 
 pub trait EmailImport: Sync + Send {
@@ -49,10 +48,19 @@ impl EmailImport for Server {
 
         // Obtain import access token
         let import_access_token = if account_id != access_token.primary_id() {
-            self.get_access_token(account_id)
-                .await
-                .caused_by(trc::location!())?
-                .into()
+            #[cfg(feature = "test_mode")]
+            {
+                std::sync::Arc::new(AccessToken::from_id(account_id)).into()
+            }
+
+            #[cfg(not(feature = "test_mode"))]
+            {
+                use trc::AddContext;
+                self.get_access_token(account_id)
+                    .await
+                    .caused_by(trc::location!())?
+                    .into()
+            }
         } else {
             None
         };
