@@ -65,10 +65,8 @@ impl PostgresStore {
             .ok()?,
         };
 
-        if create_tables {
-            if let Err(err) = db.create_tables().await {
-                config.new_build_error(prefix.as_str(), format!("Failed to create tables: {err}"));
-            }
+        if create_tables && let Err(err) = db.create_tables().await {
+            config.new_build_error(prefix.as_str(), format!("Failed to create tables: {err}"));
         }
 
         Some(db)
