@@ -90,7 +90,7 @@ async fn jmap_tests() {
     .await;
 
     webhooks::test(&mut params).await;
-    email_query::test(&mut params, delete).await;
+    /*email_query::test(&mut params, delete).await;
     email_get::test(&mut params).await;
     email_set::test(&mut params).await;
     email_parse::test(&mut params).await;
@@ -113,7 +113,7 @@ async fn jmap_tests() {
     websocket::test(&mut params).await;
     quota::test(&mut params).await;
     crypto::test(&mut params).await;
-    blob::test(&mut params).await;
+    blob::test(&mut params).await;*/
     permissions::test(&params).await;
     purge::test(&mut params).await;
     enterprise::test(&mut params).await;
@@ -813,7 +813,7 @@ port = 9999
 protocol = "smtp"
 
 [queue.route."mock-smtp".tls]
-enable = false
+implicit = false
 allow-invalid-certs = true
 
 [session.extensions]
