@@ -42,14 +42,14 @@ pub async fn test(params: &JMAPTest) {
         .await
         .unwrap()
         .unwrap_data();
-    server
+    let revision = server
         .get_access_token(account_id)
         .await
         .unwrap()
         .validate_permissions(
             Permission::all().filter(|p| p.is_user_permission() && *p != Permission::Pop3Dele),
         )
-        .validate_revision(0);
+        .revision;
 
     // Create multiple roles
     for (role, permissions, parent_role) in &[
@@ -125,21 +125,24 @@ pub async fn test(params: &JMAPTest) {
     .await
     .unwrap()
     .unwrap_data();
-    server
-        .get_access_token(account_id)
-        .await
-        .unwrap()
-        .validate_permissions([
-            Permission::EmailSend,
-            Permission::EmailReceive,
-            Permission::JmapEmailQuery,
-            Permission::AuthenticateOauth,
-            Permission::ImapAuthenticate,
-            Permission::ImapList,
-            Permission::Pop3Authenticate,
-            Permission::Pop3List,
-        ])
-        .validate_revision(1);
+    assert_ne!(
+        server
+            .get_access_token(account_id)
+            .await
+            .unwrap()
+            .validate_permissions([
+                Permission::EmailSend,
+                Permission::EmailReceive,
+                Permission::JmapEmailQuery,
+                Permission::AuthenticateOauth,
+                Permission::ImapAuthenticate,
+                Permission::ImapList,
+                Permission::Pop3Authenticate,
+                Permission::Pop3List,
+            ])
+            .revision,
+        revision
+    );
 
     // Query all principals
     api.get::<List<PrincipalSet>>("/api/principal")
@@ -842,7 +845,6 @@ trait ValidatePermissions {
         expected_permissions: impl IntoIterator<Item = Permission>,
     ) -> Self;
     fn validate_tenant(self, tenant_id: u32, tenant_quota: u64) -> Self;
-    fn validate_revision(self, revision: u64) -> Self;
 }
 
 impl ValidatePermissions for Arc<AccessToken> {
@@ -887,9 +889,4 @@ impl ValidatePermissions for Arc<AccessToken> {
         );
         self
     }
-
-    fn validate_revision(self, revision: u64) -> Self {
-        assert_eq!(self.revision, revision);
-        self
-    }
 }
