@@ -37,7 +37,7 @@ use quick_xml::Reader;
 use quick_xml::events::Event;
 use services::SpawnServices;
 use smtp::{SpawnQueueManager, core::SmtpSessionManager};
-use std::str;
+use std::{borrow::Cow, str};
 use std::{
     sync::Arc,
     time::{Duration, Instant},
@@ -73,11 +73,13 @@ fn webdav_tests() {
         .unwrap()
         .block_on(async {
             // Prepare settings
+            let assisted_discovery = std::env::var("ASSISTED_DISCOVERY").unwrap_or_default() == "1";
             let start_time = Instant::now();
             let delete = true;
             let handle = init_webdav_tests(
                 &std::env::var("STORE")
                     .expect("Missing store type. Try running `STORE=<store_type> cargo test`"),
+                assisted_discovery,
                 delete,
             )
             .await;
@@ -85,12 +87,12 @@ fn webdav_tests() {
             basic::test(&handle).await;
             put_get::test(&handle).await;
             mkcol::test(&handle).await;
-            copy_move::test(&handle).await;
-            prop::test(&handle).await;
+            copy_move::test(&handle, assisted_discovery).await;
+            prop::test(&handle, assisted_discovery).await;
             multiget::test(&handle).await;
             sync::test(&handle).await;
             lock::test(&handle).await;
-            principals::test(&handle).await;
+            principals::test(&handle, assisted_discovery).await;
             acl::test(&handle).await;
             card_query::test(&handle).await;
             cal_query::test(&handle).await;
@@ -121,13 +123,18 @@ pub struct WebDavTest {
     shutdown_tx: watch::Sender<bool>,
 }
 
-async fn init_webdav_tests(store_id: &str, delete_if_exists: bool) -> WebDavTest {
+async fn init_webdav_tests(
+    store_id: &str,
+    assisted_discovery: bool,
+    delete_if_exists: bool,
+) -> WebDavTest {
     // Load and parse config
     let temp_dir = TempDir::new("webdav_tests", delete_if_exists);
     let mut config = Config::new(
         add_test_certs(SERVER)
             .replace("{STORE}", store_id)
             .replace("{TMP}", &temp_dir.path.display().to_string())
+            .replace("{ASSISTED_DISCOVERY}", &assisted_discovery.to_string())
             .replace(
                 "{LEVEL}",
                 &std::env::var("LOG").unwrap_or_else(|_| "disable".to_string()),
@@ -758,10 +765,38 @@ fn flatten_xml(xml: &str) -> Vec<(String, String)> {
                 }
             }
             Event::Text(e) => {
-                let text = e.unescape().unwrap();
+                let text = e.xml_content().unwrap();
                 let trimmed = text.trim();
                 if !trimmed.is_empty() {
-                    text_content = Some(trimmed.to_string());
+                    if let Some(text_content) = text_content.as_mut() {
+                        text_content.push_str(trimmed);
+                    } else {
+                        text_content = Some(trimmed.to_string());
+                    }
+                }
+            }
+            Event::GeneralRef(entity) => {
+                let value: Cow<str> = match entity.as_ref() {
+                    b"lt" => "<".into(),
+                    b"gt" => ">".into(),
+                    b"amp" => "&".into(),
+                    b"apos" => "'".into(),
+                    b"quot" => "\"".into(),
+                    _ => {
+                        if let Ok(Some(gr)) = entity.resolve_char_ref() {
+                            gr.to_string().into()
+                        } else {
+                            std::str::from_utf8(entity.as_ref())
+                                .unwrap_or_default()
+                                .into()
+                        }
+                    }
+                };
+
+                if let Some(text_content) = text_content.as_mut() {
+                    text_content.push_str(value.as_ref());
+                } else {
+                    text_content = Some(value.into_owned());
                 }
             }
             Event::CData(e) => {
@@ -1162,7 +1197,7 @@ minimum-interval = "1s"
 auto-add = true
 
 [dav.collection]
-assisted-discovery = false
+assisted-discovery = {ASSISTED_DISCOVERY}
 
 [store."auth"]
 type = "sqlite"
